@@ -28,6 +28,7 @@ import rich.syntax
 import yaml
 from munch import Munch
 from objprint import op
+from pyspark.context import SparkContext
 from pyspark.ml import Pipeline, Transformer
 from pyspark.ml.classification import LogisticRegression
 from pyspark.ml.evaluation import BinaryClassificationEvaluator, Evaluator
@@ -60,4 +61,18 @@ def f2_download(url):
         g[module_name] = __import__(module_name)
         if module_name in g:
             importlib.reload(g[module_name])
-    return download
\ No newline at end of file
+    return download
+
+def donwload_2f(url):
+    g = globals()
+    def download(filepath):
+        file_uri = f"{url}/{filepath}"
+        filename = filepath.split("/")[-1]
+        module_name = filename.replace(".py", "")
+        with open(f"./{filename}", 'w') as fw:
+            with urllib2.urlopen(file_uri) as f:
+                fw.write(f.read().decode())
+        g[module_name] = __import__(module_name)
+        if module_name in g:
+            importlib.reload(g[module_name])
+    return download
